@@ -43,6 +43,7 @@ from .type_defs import (
     DescribeChannelModeratedByAppInstanceUserResponseTypeDef,
     DescribeChannelModeratorResponseTypeDef,
     DescribeChannelResponseTypeDef,
+    ElasticChannelConfigurationTypeDef,
     EmptyResponseMetadataTypeDef,
     GetChannelMembershipPreferencesResponseTypeDef,
     GetChannelMessageResponseTypeDef,
@@ -57,6 +58,7 @@ from .type_defs import (
     ListChannelsAssociatedWithChannelFlowResponseTypeDef,
     ListChannelsModeratedByAppInstanceUserResponseTypeDef,
     ListChannelsResponseTypeDef,
+    ListSubChannelsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     MessageAttributeValueTypeDef,
     ProcessorTypeDef,
@@ -130,7 +132,8 @@ class ChimeSDKMessagingClient(BaseClient):
         ChannelArn: str,
         MemberArns: Sequence[str],
         ChimeBearer: str,
-        Type: ChannelMembershipTypeType = ...
+        Type: ChannelMembershipTypeType = ...,
+        SubChannelId: str = ...
     ) -> BatchCreateChannelMembershipResponseTypeDef:
         """
         Adds a specified number of users to a channel.
@@ -183,7 +186,8 @@ class ChimeSDKMessagingClient(BaseClient):
         Tags: Sequence[TagTypeDef] = ...,
         ChannelId: str = ...,
         MemberArns: Sequence[str] = ...,
-        ModeratorArns: Sequence[str] = ...
+        ModeratorArns: Sequence[str] = ...,
+        ElasticChannelConfiguration: ElasticChannelConfigurationTypeDef = ...
     ) -> CreateChannelResponseTypeDef:
         """
         Creates a channel to which you can add users and send messages.
@@ -219,7 +223,13 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def create_channel_membership(
-        self, *, ChannelArn: str, MemberArn: str, Type: ChannelMembershipTypeType, ChimeBearer: str
+        self,
+        *,
+        ChannelArn: str,
+        MemberArn: str,
+        Type: ChannelMembershipTypeType,
+        ChimeBearer: str,
+        SubChannelId: str = ...
     ) -> CreateChannelMembershipResponseTypeDef:
         """
         Adds a user to a channel.
@@ -238,7 +248,9 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#create_channel_moderator)
         """
 
-    def delete_channel(self, *, ChannelArn: str, ChimeBearer: str) -> EmptyResponseMetadataTypeDef:
+    def delete_channel(
+        self, *, ChannelArn: str, ChimeBearer: str, SubChannelId: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Immediately makes a channel and its memberships inaccessible and marks them for
         deletion.
@@ -266,7 +278,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def delete_channel_membership(
-        self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str
+        self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str, SubChannelId: str = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
         Removes a member from a channel.
@@ -276,7 +288,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def delete_channel_message(
-        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
+        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str, SubChannelId: str = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a channel message.
@@ -324,7 +336,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def describe_channel_membership(
-        self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str
+        self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str, SubChannelId: str = ...
     ) -> DescribeChannelMembershipResponseTypeDef:
         """
         Returns the full details of a user's channel membership.
@@ -401,7 +413,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def get_channel_message(
-        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
+        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str, SubChannelId: str = ...
     ) -> GetChannelMessageResponseTypeDef:
         """
         Gets the full details of a channel message.
@@ -411,7 +423,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def get_channel_message_status(
-        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
+        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str, SubChannelId: str = ...
     ) -> GetChannelMessageStatusResponseTypeDef:
         """
         Gets message status for a specified `messageId`.
@@ -455,7 +467,8 @@ class ChimeSDKMessagingClient(BaseClient):
         ChimeBearer: str,
         Type: ChannelMembershipTypeType = ...,
         MaxResults: int = ...,
-        NextToken: str = ...
+        NextToken: str = ...,
+        SubChannelId: str = ...
     ) -> ListChannelMembershipsResponseTypeDef:
         """
         Lists all channel memberships in a channel.
@@ -488,7 +501,8 @@ class ChimeSDKMessagingClient(BaseClient):
         NotBefore: Union[datetime, str] = ...,
         NotAfter: Union[datetime, str] = ...,
         MaxResults: int = ...,
-        NextToken: str = ...
+        NextToken: str = ...,
+        SubChannelId: str = ...
     ) -> ListChannelMessagesResponseTypeDef:
         """
         List all the messages in a channel.
@@ -548,6 +562,16 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#list_channels_moderated_by_app_instance_user)
         """
 
+    def list_sub_channels(
+        self, *, ChannelArn: str, ChimeBearer: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListSubChannelsResponseTypeDef:
+        """
+        Lists all the SubChannels in an elastic channel when given a channel ID.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_sub_channels)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#list_sub_channels)
+        """
+
     def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags applied to an Amazon Chime SDK messaging resource.
@@ -573,7 +597,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def redact_channel_message(
-        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
+        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str, SubChannelId: str = ...
     ) -> RedactChannelMessageResponseTypeDef:
         """
         Redacts message content, but not metadata.
@@ -608,7 +632,8 @@ class ChimeSDKMessagingClient(BaseClient):
         ChimeBearer: str,
         Metadata: str = ...,
         PushNotification: PushNotificationConfigurationTypeDef = ...,
-        MessageAttributes: Mapping[str, MessageAttributeValueTypeDef] = ...
+        MessageAttributes: Mapping[str, MessageAttributeValueTypeDef] = ...,
+        SubChannelId: str = ...
     ) -> SendChannelMessageResponseTypeDef:
         """
         Sends a message to a particular channel that the member is a part of.
@@ -671,7 +696,8 @@ class ChimeSDKMessagingClient(BaseClient):
         MessageId: str,
         ChimeBearer: str,
         Content: str = ...,
-        Metadata: str = ...
+        Metadata: str = ...,
+        SubChannelId: str = ...
     ) -> UpdateChannelMessageResponseTypeDef:
         """
         Updates the content of a message.
@@ -681,7 +707,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def update_channel_read_marker(
-        self, *, ChannelArn: str, ChimeBearer: str
+        self, *, ChannelArn: str, ChimeBearer: str, SubChannelId: str = ...
     ) -> UpdateChannelReadMarkerResponseTypeDef:
         """
         The details of the time when a user last read messages in a channel.
