@@ -53,6 +53,7 @@ __all__ = (
     "MessageAttributeValueTypeDef",
     "PushNotificationConfigurationTypeDef",
     "ChannelMessageStatusStructureTypeDef",
+    "ElasticChannelConfigurationTypeDef",
     "CreateChannelBanRequestRequestTypeDef",
     "TagTypeDef",
     "CreateChannelMembershipRequestRequestTypeDef",
@@ -85,6 +86,8 @@ __all__ = (
     "ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
     "ListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
     "ListChannelsRequestRequestTypeDef",
+    "ListSubChannelsRequestRequestTypeDef",
+    "SubChannelSummaryTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "RedactChannelMessageRequestRequestTypeDef",
     "SearchFieldTypeDef",
@@ -99,7 +102,6 @@ __all__ = (
     "ChannelMembershipTypeDef",
     "ChannelModeratorSummaryTypeDef",
     "ChannelModeratorTypeDef",
-    "ChannelTypeDef",
     "ChannelFlowCallbackResponseTypeDef",
     "CreateChannelBanResponseTypeDef",
     "CreateChannelFlowResponseTypeDef",
@@ -124,11 +126,13 @@ __all__ = (
     "GetChannelMessageStatusResponseTypeDef",
     "SendChannelMessageResponseTypeDef",
     "UpdateChannelMessageResponseTypeDef",
+    "ChannelTypeDef",
     "CreateChannelRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
     "GetMessagingSessionEndpointResponseTypeDef",
     "ProcessorConfigurationTypeDef",
+    "ListSubChannelsResponseTypeDef",
     "SearchChannelsRequestRequestTypeDef",
     "BatchCreateChannelMembershipResponseTypeDef",
     "ListChannelBansResponseTypeDef",
@@ -137,7 +141,6 @@ __all__ = (
     "DescribeChannelMembershipResponseTypeDef",
     "ListChannelModeratorsResponseTypeDef",
     "DescribeChannelModeratorResponseTypeDef",
-    "DescribeChannelResponseTypeDef",
     "DescribeChannelMembershipForAppInstanceUserResponseTypeDef",
     "ListChannelMembershipsForAppInstanceUserResponseTypeDef",
     "DescribeChannelModeratedByAppInstanceUserResponseTypeDef",
@@ -148,6 +151,7 @@ __all__ = (
     "ChannelFlowCallbackRequestRequestTypeDef",
     "ListChannelMessagesResponseTypeDef",
     "GetChannelMessageResponseTypeDef",
+    "DescribeChannelResponseTypeDef",
     "ProcessorTypeDef",
     "ChannelFlowSummaryTypeDef",
     "ChannelFlowTypeDef",
@@ -162,6 +166,7 @@ AppInstanceUserMembershipSummaryTypeDef = TypedDict(
     {
         "Type": ChannelMembershipTypeType,
         "ReadMarkerTimestamp": datetime,
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -206,6 +211,7 @@ _OptionalBatchCreateChannelMembershipRequestRequestTypeDef = TypedDict(
     "_OptionalBatchCreateChannelMembershipRequestRequestTypeDef",
     {
         "Type": ChannelMembershipTypeType,
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -302,6 +308,15 @@ ChannelMessageStatusStructureTypeDef = TypedDict(
     total=False,
 )
 
+ElasticChannelConfigurationTypeDef = TypedDict(
+    "ElasticChannelConfigurationTypeDef",
+    {
+        "MaximumSubChannels": int,
+        "TargetMembershipsPerSubChannel": int,
+        "MinimumMembershipPercentage": int,
+    },
+)
+
 CreateChannelBanRequestRequestTypeDef = TypedDict(
     "CreateChannelBanRequestRequestTypeDef",
     {
@@ -319,8 +334,8 @@ TagTypeDef = TypedDict(
     },
 )
 
-CreateChannelMembershipRequestRequestTypeDef = TypedDict(
-    "CreateChannelMembershipRequestRequestTypeDef",
+_RequiredCreateChannelMembershipRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelMembershipRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MemberArn": str,
@@ -328,6 +343,21 @@ CreateChannelMembershipRequestRequestTypeDef = TypedDict(
         "ChimeBearer": str,
     },
 )
+_OptionalCreateChannelMembershipRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelMembershipRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
+
+
+class CreateChannelMembershipRequestRequestTypeDef(
+    _RequiredCreateChannelMembershipRequestRequestTypeDef,
+    _OptionalCreateChannelMembershipRequestRequestTypeDef,
+):
+    pass
+
 
 CreateChannelModeratorRequestRequestTypeDef = TypedDict(
     "CreateChannelModeratorRequestRequestTypeDef",
@@ -354,23 +384,53 @@ DeleteChannelFlowRequestRequestTypeDef = TypedDict(
     },
 )
 
-DeleteChannelMembershipRequestRequestTypeDef = TypedDict(
-    "DeleteChannelMembershipRequestRequestTypeDef",
+_RequiredDeleteChannelMembershipRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteChannelMembershipRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MemberArn": str,
         "ChimeBearer": str,
     },
 )
+_OptionalDeleteChannelMembershipRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteChannelMembershipRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
 
-DeleteChannelMessageRequestRequestTypeDef = TypedDict(
-    "DeleteChannelMessageRequestRequestTypeDef",
+
+class DeleteChannelMembershipRequestRequestTypeDef(
+    _RequiredDeleteChannelMembershipRequestRequestTypeDef,
+    _OptionalDeleteChannelMembershipRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredDeleteChannelMessageRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteChannelMessageRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MessageId": str,
         "ChimeBearer": str,
     },
 )
+_OptionalDeleteChannelMessageRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteChannelMessageRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
+
+
+class DeleteChannelMessageRequestRequestTypeDef(
+    _RequiredDeleteChannelMessageRequestRequestTypeDef,
+    _OptionalDeleteChannelMessageRequestRequestTypeDef,
+):
+    pass
+
 
 DeleteChannelModeratorRequestRequestTypeDef = TypedDict(
     "DeleteChannelModeratorRequestRequestTypeDef",
@@ -381,13 +441,27 @@ DeleteChannelModeratorRequestRequestTypeDef = TypedDict(
     },
 )
 
-DeleteChannelRequestRequestTypeDef = TypedDict(
-    "DeleteChannelRequestRequestTypeDef",
+_RequiredDeleteChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteChannelRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
     },
 )
+_OptionalDeleteChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteChannelRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
+
+
+class DeleteChannelRequestRequestTypeDef(
+    _RequiredDeleteChannelRequestRequestTypeDef, _OptionalDeleteChannelRequestRequestTypeDef
+):
+    pass
+
 
 DescribeChannelBanRequestRequestTypeDef = TypedDict(
     "DescribeChannelBanRequestRequestTypeDef",
@@ -414,14 +488,29 @@ DescribeChannelMembershipForAppInstanceUserRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeChannelMembershipRequestRequestTypeDef = TypedDict(
-    "DescribeChannelMembershipRequestRequestTypeDef",
+_RequiredDescribeChannelMembershipRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeChannelMembershipRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MemberArn": str,
         "ChimeBearer": str,
     },
 )
+_OptionalDescribeChannelMembershipRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeChannelMembershipRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
+
+
+class DescribeChannelMembershipRequestRequestTypeDef(
+    _RequiredDescribeChannelMembershipRequestRequestTypeDef,
+    _OptionalDescribeChannelMembershipRequestRequestTypeDef,
+):
+    pass
+
 
 DescribeChannelModeratedByAppInstanceUserRequestRequestTypeDef = TypedDict(
     "DescribeChannelModeratedByAppInstanceUserRequestRequestTypeDef",
@@ -467,23 +556,52 @@ GetChannelMembershipPreferencesRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetChannelMessageRequestRequestTypeDef = TypedDict(
-    "GetChannelMessageRequestRequestTypeDef",
+_RequiredGetChannelMessageRequestRequestTypeDef = TypedDict(
+    "_RequiredGetChannelMessageRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MessageId": str,
         "ChimeBearer": str,
     },
 )
+_OptionalGetChannelMessageRequestRequestTypeDef = TypedDict(
+    "_OptionalGetChannelMessageRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
 
-GetChannelMessageStatusRequestRequestTypeDef = TypedDict(
-    "GetChannelMessageStatusRequestRequestTypeDef",
+
+class GetChannelMessageRequestRequestTypeDef(
+    _RequiredGetChannelMessageRequestRequestTypeDef, _OptionalGetChannelMessageRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredGetChannelMessageStatusRequestRequestTypeDef = TypedDict(
+    "_RequiredGetChannelMessageStatusRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MessageId": str,
         "ChimeBearer": str,
     },
 )
+_OptionalGetChannelMessageStatusRequestRequestTypeDef = TypedDict(
+    "_OptionalGetChannelMessageStatusRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
+
+
+class GetChannelMessageStatusRequestRequestTypeDef(
+    _RequiredGetChannelMessageStatusRequestRequestTypeDef,
+    _OptionalGetChannelMessageStatusRequestRequestTypeDef,
+):
+    pass
+
 
 MessagingSessionEndpointTypeDef = TypedDict(
     "MessagingSessionEndpointTypeDef",
@@ -583,6 +701,7 @@ _OptionalListChannelMembershipsRequestRequestTypeDef = TypedDict(
         "Type": ChannelMembershipTypeType,
         "MaxResults": int,
         "NextToken": str,
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -610,6 +729,7 @@ _OptionalListChannelMessagesRequestRequestTypeDef = TypedDict(
         "NotAfter": Union[datetime, str],
         "MaxResults": int,
         "NextToken": str,
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -717,6 +837,38 @@ class ListChannelsRequestRequestTypeDef(
     pass
 
 
+_RequiredListSubChannelsRequestRequestTypeDef = TypedDict(
+    "_RequiredListSubChannelsRequestRequestTypeDef",
+    {
+        "ChannelArn": str,
+        "ChimeBearer": str,
+    },
+)
+_OptionalListSubChannelsRequestRequestTypeDef = TypedDict(
+    "_OptionalListSubChannelsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListSubChannelsRequestRequestTypeDef(
+    _RequiredListSubChannelsRequestRequestTypeDef, _OptionalListSubChannelsRequestRequestTypeDef
+):
+    pass
+
+
+SubChannelSummaryTypeDef = TypedDict(
+    "SubChannelSummaryTypeDef",
+    {
+        "SubChannelId": str,
+        "MembershipCount": int,
+    },
+    total=False,
+)
+
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -724,14 +876,29 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-RedactChannelMessageRequestRequestTypeDef = TypedDict(
-    "RedactChannelMessageRequestRequestTypeDef",
+_RequiredRedactChannelMessageRequestRequestTypeDef = TypedDict(
+    "_RequiredRedactChannelMessageRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MessageId": str,
         "ChimeBearer": str,
     },
 )
+_OptionalRedactChannelMessageRequestRequestTypeDef = TypedDict(
+    "_OptionalRedactChannelMessageRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
+
+
+class RedactChannelMessageRequestRequestTypeDef(
+    _RequiredRedactChannelMessageRequestRequestTypeDef,
+    _OptionalRedactChannelMessageRequestRequestTypeDef,
+):
+    pass
+
 
 SearchFieldTypeDef = TypedDict(
     "SearchFieldTypeDef",
@@ -763,6 +930,7 @@ _OptionalUpdateChannelMessageRequestRequestTypeDef = TypedDict(
     {
         "Content": str,
         "Metadata": str,
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -775,13 +943,28 @@ class UpdateChannelMessageRequestRequestTypeDef(
     pass
 
 
-UpdateChannelReadMarkerRequestRequestTypeDef = TypedDict(
-    "UpdateChannelReadMarkerRequestRequestTypeDef",
+_RequiredUpdateChannelReadMarkerRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateChannelReadMarkerRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
     },
 )
+_OptionalUpdateChannelReadMarkerRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateChannelReadMarkerRequestRequestTypeDef",
+    {
+        "SubChannelId": str,
+    },
+    total=False,
+)
+
+
+class UpdateChannelReadMarkerRequestRequestTypeDef(
+    _RequiredUpdateChannelReadMarkerRequestRequestTypeDef,
+    _OptionalUpdateChannelReadMarkerRequestRequestTypeDef,
+):
+    pass
+
 
 _RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateChannelRequestRequestTypeDef",
@@ -814,6 +997,7 @@ BatchChannelMembershipsTypeDef = TypedDict(
         "Type": ChannelMembershipTypeType,
         "Members": List[IdentityTypeDef],
         "ChannelArn": str,
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -854,6 +1038,7 @@ ChannelMembershipTypeDef = TypedDict(
         "ChannelArn": str,
         "CreatedTimestamp": datetime,
         "LastUpdatedTimestamp": datetime,
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -877,23 +1062,6 @@ ChannelModeratorTypeDef = TypedDict(
     total=False,
 )
 
-ChannelTypeDef = TypedDict(
-    "ChannelTypeDef",
-    {
-        "Name": str,
-        "ChannelArn": str,
-        "Mode": ChannelModeType,
-        "Privacy": ChannelPrivacyType,
-        "Metadata": str,
-        "CreatedBy": IdentityTypeDef,
-        "CreatedTimestamp": datetime,
-        "LastMessageTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
-        "ChannelFlowArn": str,
-    },
-    total=False,
-)
-
 ChannelFlowCallbackResponseTypeDef = TypedDict(
     "ChannelFlowCallbackResponseTypeDef",
     {
@@ -925,6 +1093,7 @@ CreateChannelMembershipResponseTypeDef = TypedDict(
     {
         "ChannelArn": str,
         "Member": IdentityTypeDef,
+        "SubChannelId": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -958,6 +1127,7 @@ RedactChannelMessageResponseTypeDef = TypedDict(
     {
         "ChannelArn": str,
         "MessageId": str,
+        "SubChannelId": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -974,6 +1144,7 @@ UpdateChannelReadMarkerResponseTypeDef = TypedDict(
     "UpdateChannelReadMarkerResponseTypeDef",
     {
         "ChannelArn": str,
+        "SubChannelId": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -1051,6 +1222,7 @@ _OptionalChannelMessageCallbackTypeDef = TypedDict(
         "Metadata": str,
         "PushNotification": PushNotificationConfigurationTypeDef,
         "MessageAttributes": Mapping[str, MessageAttributeValueTypeDef],
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -1079,6 +1251,7 @@ _OptionalSendChannelMessageRequestRequestTypeDef = TypedDict(
         "Metadata": str,
         "PushNotification": PushNotificationConfigurationTypeDef,
         "MessageAttributes": Mapping[str, MessageAttributeValueTypeDef],
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -1125,6 +1298,7 @@ ChannelMessageTypeDef = TypedDict(
         "Persistence": ChannelMessagePersistenceTypeType,
         "Status": ChannelMessageStatusStructureTypeDef,
         "MessageAttributes": Dict[str, MessageAttributeValueTypeDef],
+        "SubChannelId": str,
     },
     total=False,
 )
@@ -1143,6 +1317,7 @@ SendChannelMessageResponseTypeDef = TypedDict(
         "ChannelArn": str,
         "MessageId": str,
         "Status": ChannelMessageStatusStructureTypeDef,
+        "SubChannelId": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -1153,10 +1328,29 @@ UpdateChannelMessageResponseTypeDef = TypedDict(
         "ChannelArn": str,
         "MessageId": str,
         "Status": ChannelMessageStatusStructureTypeDef,
+        "SubChannelId": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
+ChannelTypeDef = TypedDict(
+    "ChannelTypeDef",
+    {
+        "Name": str,
+        "ChannelArn": str,
+        "Mode": ChannelModeType,
+        "Privacy": ChannelPrivacyType,
+        "Metadata": str,
+        "CreatedBy": IdentityTypeDef,
+        "CreatedTimestamp": datetime,
+        "LastMessageTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "ChannelFlowArn": str,
+        "ElasticChannelConfiguration": ElasticChannelConfigurationTypeDef,
+    },
+    total=False,
+)
+
 _RequiredCreateChannelRequestRequestTypeDef = TypedDict(
     "_RequiredCreateChannelRequestRequestTypeDef",
     {
@@ -1176,6 +1370,7 @@ _OptionalCreateChannelRequestRequestTypeDef = TypedDict(
         "ChannelId": str,
         "MemberArns": Sequence[str],
         "ModeratorArns": Sequence[str],
+        "ElasticChannelConfiguration": ElasticChannelConfigurationTypeDef,
     },
     total=False,
 )
@@ -1218,6 +1413,16 @@ ProcessorConfigurationTypeDef = TypedDict(
     },
 )
 
+ListSubChannelsResponseTypeDef = TypedDict(
+    "ListSubChannelsResponseTypeDef",
+    {
+        "ChannelArn": str,
+        "SubChannels": List[SubChannelSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 _RequiredSearchChannelsRequestRequestTypeDef = TypedDict(
     "_RequiredSearchChannelsRequestRequestTypeDef",
     {
@@ -1304,14 +1509,6 @@ DescribeChannelModeratorResponseTypeDef = TypedDict(
     },
 )
 
-DescribeChannelResponseTypeDef = TypedDict(
-    "DescribeChannelResponseTypeDef",
-    {
-        "Channel": ChannelTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
 DescribeChannelMembershipForAppInstanceUserResponseTypeDef = TypedDict(
     "DescribeChannelMembershipForAppInstanceUserResponseTypeDef",
     {
@@ -1406,6 +1603,7 @@ ListChannelMessagesResponseTypeDef = TypedDict(
         "ChannelArn": str,
         "NextToken": str,
         "ChannelMessages": List[ChannelMessageSummaryTypeDef],
+        "SubChannelId": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -1418,6 +1616,14 @@ GetChannelMessageResponseTypeDef = TypedDict(
     },
 )
 
+DescribeChannelResponseTypeDef = TypedDict(
+    "DescribeChannelResponseTypeDef",
+    {
+        "Channel": ChannelTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ProcessorTypeDef = TypedDict(
     "ProcessorTypeDef",
     {
